==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'In afwachting',
	'articles_meme_auteur' => 'Alle artikels van deze auteur',
	'articles_off' => 'Geblokkeerd ',
	'articles_publie' => 'Gepubliceerd ',
	'articles_refuse' => 'Uitgewist ',
	'articles_tous' => 'Alles',
	'aucun_article_syndic' => 'Geen gesyndiceerd artikel',
	'avis_echec_syndication_01' => 'De syndicatie is mislukt : de aangeduide backend is niet te ontcijferen of stelt geen enkel artikel voor.',
	'avis_echec_syndication_02' => 'De syndicatie is mislukt : het is onmogelijk de backend van deze site te bereiken.',
	'avis_site_introuvable' => 'Site onvindbaar',
	'avis_site_syndique_probleme' => 'Opgelet: syndicatie van deze site heeft een probleem ondervonden ; het systeem wordt dus tijdelijk onderbroken. Controleer het adres van het bestand van syndicatie van deze site (<b>@url_syndic@</b>), en probeer nogmaals de informatie binnen te halen.',
	'avis_sites_probleme_syndication' => 'Deze sites hebben een probleem met syndicatie',
	'avis_sites_syndiques_probleme' => 'Deze gesyndiceerde sites hebben een probleem',

	// B
	'bouton_exporter' => 'Exporteren',
	'bouton_importer' => 'Importeren',
	'bouton_radio_modere_posteriori' => 'nadien modereren',
	'bouton_radio_modere_priori' => 'vooraf modereren',
	'bouton_radio_non_syndication' => 'Geen syndicatie',
	'bouton_radio_syndication' => 'Syndicatie :',

	// C
	'confirmer_purger_syndication' => 'Ben je zeker alle gesyndiceerde artikels uit deze website te willen uitwissen ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adres van het bestand voor syndicatie :',
	'entree_adresse_site' => '<b>website adres</b> [verplicht]',
	'entree_description_site' => 'Site beschrijving',
	'erreur_fichier_format_inconnu' => 'Formaat van het bestand @fichier@ wordt niet aanvaard.',
	'erreur_fichier_incorrect' => 'Het bestand kon niet gelezen worden.',

	// F
	'form_prop_nom_site' => 'Naam van de website',

	// I
	'icone_article_syndic' => 'Gesyndiceerd artikel',
	'icone_articles_syndic' => 'Gesyndiceerd artikels',
	'icone_controler_syndication' => 'Publicatie van de gesyndiceerd artikels',
	'icone_modifier_site' => 'Deze site wijzigen',
	'icone_referencer_nouveau_site' => 'Een nieuwe site koppelen',
	'icone_site_reference' => 'Vermelde sites',
	'icone_supprimer_article' => 'Artikel uitwissen',
	'icone_supprimer_articles' => 'Deze artikels uitwissen',
	'icone_valider_article' => 'Artikel goedkeuren',
	'icone_valider_articles' => 'Deze artikels goedkeuren ',
	'icone_voir_sites_references' => 'Gekoppelde sites zien',
	'info_1_site_importe' => '1 site werd geïmporteerd',
	'info_a_valider' => '[ter goedkeuring]',
	'info_aucun_site_importe' => 'Geen enkele site kon worden geïmporteerd',
	'info_bloquer' => 'blokkeren',
	'info_bloquer_lien' => 'deze koppeling blokkeren',
	'info_derniere_syndication' => 'De laatste syndicatie van deze site heeft plaatsgevonden op ',
	'info_liens_syndiques_1' => 'gesyndiceerde koppelingen',
	'info_liens_syndiques_2' => 'wachten op goedkeuring.',
	'info_nb_sites_importes' => '@nb@ sites werden geïmporteerd',
	'info_nom_site_2' => '<b>Naam van de website</b> [verplicht]',
	'info_panne_site_syndique' => 'Gesyndiceerde site is niet bereikbaar',
	'info_probleme_grave' => 'probleem van',
	'info_question_proposer_site' => 'Wie kan referentiesites voorstellen?',
	'info_retablir_lien' => 'deze link hernieuwen',
	'info_site_attente' => 'website ter goedkeuring voorgelegd',
	'info_site_propose' => 'Site voorgesteld op :',
	'info_site_reference' => 'Online gekoppelde site',
	'info_site_refuse' => 'Website weigerd',
	'info_site_syndique' => 'Gesyndiceerde site...',
	'info_site_valider' => 'Goed te keuren sites',
	'info_sites_referencer' => 'Een site koppelen',
	'info_sites_refuses' => 'De geweigerde websites',
	'info_statut_site_1' => 'Deze site is:',
	'info_statut_site_2' => 'Gepubliceerd',
	'info_statut_site_3' => 'Voorgesteld',
	'info_statut_site_4' => 'Naar de vuilnisbak',
	'info_syndication' => 'nieuwsovername (syndicatie) :',
	'info_syndication_articles' => 'artikel(s)',
	'item_bloquer_liens_syndiques' => 'Gesyndiceerde koppelingen tegenhouden voor goedkeuring ',
	'item_gerer_annuaire_site_web' => 'Een adresboek van de websites aanmaken',
	'item_non_bloquer_liens_syndiques' => 'Koppelingen komende van de syndicatie niet blokkeren',
	'item_non_gerer_annuaire_site_web' => 'Adresboek van websites desactiveren',
	'item_non_utiliser_syndication' => 'Automatische syndicatie niet gebruiken',
	'item_utiliser_syndication' => 'Automatische syndicatie gebruiken',

	// L
	'label_exporter_avec_mots_cles_1' => 'Trefwoorden als tags exporteren',
	'label_exporter_id_parent' => 'De rubrieken van sites exporteren',
	'label_exporter_publie_seulement_1' => 'Enkel gepubliceerde sites exporteren',
	'label_fichier_import' => 'HTML bestand',
	'label_importer_les_tags_1' => 'Tags als trefwoord importeren',
	'label_importer_statut_publie_1' => 'Sites automatisch publiceren ',
	'lien_mise_a_jour_syndication' => 'Update nu',
	'lien_nouvelle_recuperation' => 'Probeer de gegevens opnieuw te vinden',
	'lien_purger_syndication' => 'Alle gesyndiceerde artikels uitwissen',

	// N
	'nombre_articles_syndic' => '@nb@ gesyndiceerde artikels ',

	// S
	'statut_off' => 'Uitgewist',
	'statut_prop' => 'In afwachting',
	'statut_publie' => 'Gepubliceerd',
	'syndic_choix_moderation' => 'Wat te doen met volgende links afkomstig van deze site ?',
	'syndic_choix_oublier' => 'Wat te doen met links die niet langer voorkomen in het bestand voor syndicatie ?',
	'syndic_choix_resume' => 'Sommige sites verspreiden de volledige tekst van een artikel. Indien deze beschikbaar is, wil je hem dan ontvangen :',
	'syndic_lien_obsolete' => 'obsoleet link',
	'syndic_option_miroir' => 'automatisch blokkeren',
	'syndic_option_oubli' => 'uitwissen (na @mois@ maanden)',
	'syndic_option_resume_non' => 'de volledige inhoud van de artikels (in HTML formaat)',
	'syndic_option_resume_oui' => 'een eenvoudige samenvattig (tekstformaat)',
	'syndic_options' => 'Syndicatie opties :',

	// T
	'texte_expliquer_export_bookmarks' => 'Je kan een lijst van sites exporteren in HTML-opmaak, om deze vervolgens te importeren in je browser of een online toepassing.',
	'texte_expliquer_import_bookmarks' => 'Je kan een lijst met sites in HTML-opmaak importeren afkomstig van je browser of een onlinetoepassing voor favorietenbeheer.',
	'texte_liens_sites_syndiques' => 'Koppelingen komende van gesyndiceerde sites kunnen op voorhand
   geblokkeerd worden; de instelling
   hieronder zegt wat de standaardinstelling is
   voor gesyndiceerde sites als ze aangemaakt worden.
   Het is vervolgens perfect mogelijk om elke koppeling
   individueel te ontgrendelen, of om per site
   te kiezen of je koppelingen wil blokkeren of niet.',
	'texte_messages_publics' => 'Publieke berichten van dit artikel :',
	'texte_non_fonction_referencement' => 'Je kan kiezen om deze automatische functie uit te schakelen en zelf aangeven welke elementen je wil opnemen voor deze site.',
	'texte_referencement_automatique' => '..<b>Geautomatiseerde koppelen van een site</b><br />U kunt een website snel verwijzen door het verlangde naar URL adres, of het adres van zijn bestand van syndication hieronder aan te geven. SPIP zal de informatie automatisch terugkrijgen betreffende deze plaats (titel, beschrijving...).',
	'texte_referencement_automatique_verifier' => 'Gelieve de inlichtingen te controleren die per <tt>@url@</tt> worden verstrekt, alvorens te registreren.',
	'texte_syndication' => 'Het is mogelijk om van een site automatisch een lijst met
 nieuws, als de website het toelaat, binnen te halen.
 Hiervoor dien je de syndicatie (nieuwsovername) te
 activeren. <blockquote><i>Sommige hostingproviders laten
 dit niet toe; in dat geval kan je geen nieuwsovername
 vanaf je site laten gebeuren.</i></blockquote>',
	'titre_articles_syndiques' => 'Gesyndiceerde artikels komende van deze site',
	'titre_dernier_article_syndique' => 'Meest recente gesyndiceerde artikels',
	'titre_exporter_bookmarks' => 'Favorieten exporteren',
	'titre_importer_bookmarks' => 'Favorieten importeren',
	'titre_importer_exporter_bookmarks' => 'Importeren en exporteren van favorieten',
	'titre_page_sites_tous' => 'De referentiesites',
	'titre_referencement_sites' => 'Koppelen van sites en syndicatie',
	'titre_site_numero' => 'WEBSITE NUMMER:',
	'titre_sites_proposes' => 'Voorgestelde sites',
	'titre_sites_references_rubrique' => 'Gekoppelde sites in deze rubriek',
	'titre_sites_syndiques' => 'Gesyndiceerde sites',
	'titre_sites_tous' => 'Gekoppelde sites',
	'titre_syndication' => 'Syndicatie van websites',
	'tout_voir' => 'Alle gesyndiceerde artikels tonen',

	// U
	'un_article_syndic' => '1 gesyndiceerd artikel'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'In afwachting',
	'articles_meme_auteur' => 'Alle artikels van deze auteur',
	'articles_off' => 'Geblokkeerd ',
	'articles_publie' => 'Gepubliceerd ',
	'articles_refuse' => 'Uitgewist ',
	'articles_tous' => 'Alles',
	'aucun_article_syndic' => 'Geen gesyndiceerd artikel',
	'avis_echec_syndication_01' => 'De syndicatie is mislukt : de aangeduide backend is niet te ontcijferen of stelt geen enkel artikel voor.',
	'avis_echec_syndication_02' => 'De syndicatie is mislukt : het is onmogelijk de backend van deze site te bereiken.',
	'avis_site_introuvable' => 'Site onvindbaar',
	'avis_site_syndique_probleme' => 'Opgelet: syndicatie van deze site heeft een probleem ondervonden ; het systeem wordt dus tijdelijk onderbroken. Controleer het adres van het bestand van syndicatie van deze site (<b>@url_syndic@</b>), en probeer nogmaals de informatie binnen te halen.',
	'avis_sites_probleme_syndication' => 'Deze sites hebben een probleem met syndicatie',
	'avis_sites_syndiques_probleme' => 'Deze gesyndiceerde sites hebben een probleem',

	// B
	'bouton_exporter' => 'Exporteren',
	'bouton_importer' => 'Importeren',
	'bouton_radio_modere_posteriori' => 'nadien modereren',
	'bouton_radio_modere_priori' => 'vooraf modereren',
	'bouton_radio_non_syndication' => 'Geen syndicatie',
	'bouton_radio_syndication' => 'Syndicatie :',

	// C
	'confirmer_purger_syndication' => 'Ben je zeker alle gesyndiceerde artikels uit deze website te willen uitwissen ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adres van het bestand voor syndicatie :',
	'entree_adresse_site' => '<b>website adres</b> [verplicht]',
	'entree_description_site' => 'Site beschrijving',
	'erreur_fichier_format_inconnu' => 'Formaat van het bestand @fichier@ wordt niet aanvaard.',
	'erreur_fichier_incorrect' => 'Het bestand kon niet gelezen worden.',

	// F
	'form_prop_nom_site' => 'Naam van de website',

	// I
	'icone_article_syndic' => 'Gesyndiceerd artikel',
	'icone_articles_syndic' => 'Gesyndiceerd artikels',
	'icone_controler_syndication' => 'Publicatie van de gesyndiceerd artikels',
	'icone_modifier_site' => 'Deze site wijzigen',
	'icone_referencer_nouveau_site' => 'Een nieuwe site koppelen',
	'icone_site_reference' => 'Vermelde sites',
	'icone_supprimer_article' => 'Artikel uitwissen',
	'icone_supprimer_articles' => 'Deze artikels uitwissen',
	'icone_valider_article' => 'Artikel goedkeuren',
	'icone_valider_articles' => 'Deze artikels goedkeuren ',
	'icone_voir_sites_references' => 'Gekoppelde sites zien',
	'info_1_article_syndique' => 'Gesyndiceerde 1 artikel',
	'info_1_site' => '1 site',
	'info_1_site_importe' => '1 site werd geïmporteerd',
	'info_a_valider' => '[ter goedkeuring]',
	'info_aucun_article_syndique' => 'Geen gesyndiceerde artikel',
	'info_aucun_site' => 'Geen site',
	'info_aucun_site_importe' => 'Geen enkele site kon worden geïmporteerd',
	'info_bloquer' => 'blokkeren',
	'info_bloquer_lien' => 'deze koppeling blokkeren',
	'info_derniere_syndication' => 'De laatste syndicatie van deze site heeft plaatsgevonden op ',
	'info_liens_syndiques_1' => 'gesyndiceerde koppelingen',
	'info_liens_syndiques_2' => 'wachten op goedkeuring.',
	'info_nb_articles_syndiques' => '@nb@ gesyndiceerde artikelen',
	'info_nb_sites' => '@nb@ sites',
	'info_nb_sites_importes' => '@nb@ sites werden geïmporteerd',
	'info_nom_site_2' => '<b>Naam van de website</b> [verplicht]',
	'info_panne_site_syndique' => 'Gesyndiceerde site is niet bereikbaar',
	'info_probleme_grave' => 'probleem van',
	'info_question_proposer_site' => 'Wie kan referentiesites voorstellen?',
	'info_retablir_lien' => 'deze link hernieuwen',
	'info_site_attente' => 'website ter goedkeuring voorgelegd',
	'info_site_propose' => 'Site voorgesteld op :',
	'info_site_reference' => 'Online gekoppelde site',
	'info_site_refuse' => 'Website weigerd',
	'info_site_syndique' => 'Gesyndiceerde site...',
	'info_site_valider' => 'Goed te keuren sites',
	'info_sites_referencer' => 'Een site koppelen',
	'info_sites_refuses' => 'De geweigerde websites',
	'info_statut_site_1' => 'Deze site is:',
	'info_statut_site_2' => 'Gepubliceerd',
	'info_statut_site_3' => 'Voorgesteld',
	'info_statut_site_4' => 'Naar de vuilnisbak',
	'info_syndication' => 'nieuwsovername (syndicatie) :',
	'info_syndication_articles' => 'artikel(s)',
	'item_bloquer_liens_syndiques' => 'Gesyndiceerde koppelingen tegenhouden voor goedkeuring ',
	'item_gerer_annuaire_site_web' => 'Een adresboek van de websites aanmaken',
	'item_non_bloquer_liens_syndiques' => 'Koppelingen komende van de syndicatie niet blokkeren',
	'item_non_gerer_annuaire_site_web' => 'Adresboek van websites desactiveren',
	'item_non_utiliser_syndication' => 'Automatische syndicatie niet gebruiken',
	'item_utiliser_syndication' => 'Automatische syndicatie gebruiken',

	// L
	'label_exporter_avec_mots_cles_1' => 'Trefwoorden als tags exporteren',
	'label_exporter_id_parent' => 'De rubrieken van sites exporteren',
	'label_exporter_publie_seulement_1' => 'Enkel gepubliceerde sites exporteren',
	'label_fichier_import' => 'HTML bestand',
	'label_importer_les_tags_1' => 'Tags als trefwoord importeren',
	'label_importer_statut_publie_1' => 'Sites automatisch publiceren ',
	'lien_mise_a_jour_syndication' => 'Update nu',
	'lien_nouvelle_recuperation' => 'Probeer de gegevens opnieuw te vinden',
	'lien_purger_syndication' => 'Alle gesyndiceerde artikels uitwissen',

	// N
	'nombre_articles_syndic' => '@nb@ gesyndiceerde artikels ',

	// S
	'statut_off' => 'Uitgewist',
	'statut_prop' => 'In afwachting',
	'statut_publie' => 'Gepubliceerd',
	'syndic_choix_moderation' => 'Wat te doen met volgende links afkomstig van deze site ?',
	'syndic_choix_oublier' => 'Wat te doen met links die niet langer voorkomen in het bestand voor syndicatie ?',
	'syndic_choix_resume' => 'Sommige sites verspreiden de volledige tekst van een artikel. Indien deze beschikbaar is, wil je hem dan ontvangen :',
	'syndic_lien_obsolete' => 'obsoleet link',
	'syndic_option_miroir' => 'automatisch blokkeren',
	'syndic_option_oubli' => 'uitwissen (na @mois@ maanden)',
	'syndic_option_resume_non' => 'de volledige inhoud van de artikels (in HTML formaat)',
	'syndic_option_resume_oui' => 'een eenvoudige samenvattig (tekstformaat)',
	'syndic_options' => 'Syndicatie opties :',

	// T
	'texte_expliquer_export_bookmarks' => 'Je kan een lijst van sites exporteren in HTML-opmaak, om deze vervolgens te importeren in je browser of een online toepassing.',
	'texte_expliquer_import_bookmarks' => 'Je kan een lijst met sites in HTML-opmaak importeren afkomstig van je browser of een onlinetoepassing voor favorietenbeheer.',
	'texte_liens_sites_syndiques' => 'Koppelingen komende van gesyndiceerde sites kunnen op voorhand
   geblokkeerd worden; de instelling
   hieronder zegt wat de standaardinstelling is
   voor gesyndiceerde sites als ze aangemaakt worden.
   Het is vervolgens perfect mogelijk om elke koppeling
   individueel te ontgrendelen, of om per site
   te kiezen of je koppelingen wil blokkeren of niet.',
	'texte_messages_publics' => 'Publieke berichten van dit artikel :',
	'texte_non_fonction_referencement' => 'Je kan kiezen om deze automatische functie uit te schakelen en zelf aangeven welke elementen je wil opnemen voor deze site.',
	'texte_referencement_automatique' => '..<b>Geautomatiseerde koppelen van een site</b><br />U kunt een website snel verwijzen door het verlangde naar URL adres, of het adres van zijn bestand van syndication hieronder aan te geven. SPIP zal de informatie automatisch terugkrijgen betreffende deze plaats (titel, beschrijving...).',
	'texte_referencement_automatique_verifier' => 'Gelieve de inlichtingen te controleren die per <tt>@url@</tt> worden verstrekt, alvorens te registreren.',
	'texte_syndication' => 'Het is mogelijk om van een site automatisch een lijst met
 nieuws, als de website het toelaat, binnen te halen.
 Hiervoor dien je de syndicatie (nieuwsovername) te
 activeren. <blockquote><i>Sommige hostingproviders laten
 dit niet toe; in dat geval kan je geen nieuwsovername
 vanaf je site laten gebeuren.</i></blockquote>',
	'titre_articles_syndiques' => 'Gesyndiceerde artikels komende van deze site',
	'titre_dernier_article_syndique' => 'Meest recente gesyndiceerde artikels',
	'titre_exporter_bookmarks' => 'Favorieten exporteren',
	'titre_importer_bookmarks' => 'Favorieten importeren',
	'titre_importer_exporter_bookmarks' => 'Importeren en exporteren van favorieten',
	'titre_page_sites_tous' => 'De referentiesites',
	'titre_referencement_sites' => 'Koppelen van sites en syndicatie',
	'titre_site_numero' => 'WEBSITE NUMMER:',
	'titre_sites_proposes' => 'Voorgestelde sites',
	'titre_sites_references_rubrique' => 'Gekoppelde sites in deze rubriek',
	'titre_sites_syndiques' => 'Gesyndiceerde sites',
	'titre_sites_tous' => 'Gekoppelde sites',
	'titre_syndication' => 'Syndicatie van websites',
	'tout_voir' => 'Alle gesyndiceerde artikels tonen',

	// U
	'un_article_syndic' => '1 gesyndiceerd artikel'
);

?>
